<?php

namespace LQDN\Handler;

use Doctrine\DBAL\Connection;
use LQDN\Command\DonationInvalidateCommand;
use LQDN\Command\DonationResetPdfCommand;
use LQDN\Command\DonationValidateCommand;

class DonationHandler
{
    private $connection;

    public function __construct(Connection $connection)
    {
        $this->connection = $connection;
    }

    /**
     * Validate a donation.
     *
     * @param DonationValidateCommand $command
     */
    public function handleDonationValidateCommand(DonationValidateCommand $command)
    {
        $this->connection->executeUpdate('UPDATE dons SET status = status + 1 WHERE id = :id AND status IN (0, 100)', ['id' => $command->getId()]);
    }

    /**
     * Invalidate a donation.
     *
     * @param DonationInvalidateCommand $command
     */
    public function handleDonationInvalidateCommand(DonationInvalidateCommand $command)
    {
        $this->connection->executeUpdate('UPDATE dons SET status = status - 1 WHERE id = :id AND status IN (1, 101)', ['id' => $command->getId()]);
    }

    /**
     * Reset the PDF of a donation.
     *
     * @param DonationResetPdfCommand $command
     */
    public function handleDonationResetPdfCommand(DonationResetPdfCommand $command)
    {
        $this->connection->executeUpdate('UPDATE dons SET pdf = "" WHERE id = :id', ['id' => $command->getId()]);
    }
}
